@@ -27,6 +27,7 @@
 #include "FilteredOptionsModel.h"
 #include "FormatModel.h"
 #include "DevicesModel.h"
+
 class SkanpagePrivate;
 
 class Skanpage : public QObject
@@ -52,6 +53,7 @@ class Skanpage : public QObject
     Q_PROPERTY(ScanSplit scanSplit READ scanSplit WRITE setScanSplit NOTIFY scanSplitChanged)
     Q_PROPERTY(QList<QRectF> scanSubAreas READ scanSubAreas NOTIFY scanSubAreasChanged)
     Q_PROPERTY(QImage previewImage READ previewImage NOTIFY previewImageChanged)
+    Q_PROPERTY(bool previewImageAvailable READ previewImageAvailable NOTIFY previewImageChanged)
 
 public:
 
@@ -71,7 +73,7 @@ public:
     };
     Q_ENUM(ScanSplit)
 
-    explicit Skanpage(const QString &deviceName, QObject *parent = nullptr);
+    explicit Skanpage(const QString &deviceName, const QUrl &dumpOptionsUrl, QObject *parent = nullptr);
     ~Skanpage();
 
     QString deviceVendor() const;
@@ -84,6 +86,7 @@ public:
     void setScanSplit(ScanSplit split);
     const QList<QRectF> &scanSubAreas();
     QImage previewImage() const;
+    bool previewImageAvailable() const;
 
     int progress() const;
     int countDown() const;
@@ -98,11 +101,11 @@ public:
     SkanpageConfiguration *configuration() const;
     SkanpageState *stateConfiguration() const;
 
-    Q_INVOKABLE void preview();
+    Q_INVOKABLE void previewScan();
     Q_INVOKABLE void startScan();
     Q_INVOKABLE void cancelScan();
     Q_INVOKABLE void reloadDevicesList();
-    Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());    
+    Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());
     Q_INVOKABLE bool OCRavailable() const;
     Q_INVOKABLE void print();
     Q_INVOKABLE void registerAction(QObject* item, QObject* shortcuts, const QString &iconText);
@@ -111,6 +114,7 @@ public:
     Q_INVOKABLE void eraseSubArea(int index);
     Q_INVOKABLE bool appendSubArea(QRectF area);
     Q_INVOKABLE void selectSubArea(int index);
+    Q_INVOKABLE void importFile(const QUrl &fileUrl);
 
 Q_SIGNALS:
     void progressChanged(int progress);
@@ -121,7 +125,7 @@ Q_SIGNALS:
     void scanAreaChanged(const QRectF &area);
     void scanSplitChanged(ScanSplit split);
     void scanSubAreasChanged(const QList<QRectF> &subAreas);
-    void previewImageChanged(const QImage& preview);
+    void previewImageChanged(const QImage &preview);
     void newUserMessage(const QVariant &level, const QVariant &message);
 
 private Q_SLOTS:
